@@ -230,10 +230,15 @@ sr_vcov <- function(X,vcov.func=vcov,ope=1) {
 }
 
 # confidence intervals on the non-centrality parameter of a t-stat
+# we optionally inflate the standard error by `inflate_by` to support
+# prediction intervals
 .t_confint <- function(tstat,df,level=0.95,type=c("exact","t","Z","Mertens","Bao"),
-					 level.lo=(1-level)/2,level.hi=1-level.lo,cumulants=cumulants) {
+											 level.lo=(1-level)/2,level.hi=1-level.lo,cumulants=cumulants,
+											 inflate_by=1) {
 	type <- match.arg(type)
+	# non-trivial inflation only really supported by se methods.
 	if (type == "exact") {
+		stopifnot(inflate_by==1)
 		ci.lo <- qlambdap(level.lo,df,tstat,lower.tail=TRUE)
 		ci.hi <- qlambdap(level.hi,df,tstat,lower.tail=TRUE)
 		ci <- cbind(ci.lo,ci.hi)
@@ -254,6 +259,7 @@ sr_vcov <- function(X,vcov.func=vcov,ope=1) {
 						 se <- .t_se(tstat,df,type="Bao",cumulants=cumulants)
 						 midp <- .t_recenter(tstat,df,type=type,cumulants=cumulants)
 					 })
+		se <- inflate_by * se
 		zalp <- qnorm(c(level.lo,level.hi))
 		ci <- cbind(midp + zalp[1] * se,midp + zalp[2] * se)
 	} 
@@ -294,6 +300,9 @@ se <- function(z, type) {
 #' There should be very little difference between these except for very small
 #' sample sizes.
 #'
+#' See \sQuote{The Sharpe Ratio: Statistics and Applications},
+#' sections 2.5.1 and 3.2.3.
+#'
 #' @param z an observed Sharpe ratio statistic, of class \code{sr}.
 #' @param type estimator type. one of \code{"t", "Lo", "Mertens", "Bao"}
 #' @keywords htest
@@ -310,6 +319,7 @@ se <- function(z, type) {
 #' @template ref-Lo
 #' @template ref-Bao
 #' @template ref-Opdyke
+#' @template ref-tsrsa
 #' @references 
 #'
 #' Walck, C. "Hand-book on STATISTICAL DISTRIBUTIONS for experimentalists."
@@ -331,6 +341,20 @@ se.sr <- function(z, type=c("t","Lo","Mertens","Bao")) {
 }
 #UNFOLD
 
+
+# generalize confidence/prediction interval
+.genint <- function(object,level.lo,level.hi,type,inflate_by=1) {
+	tstat <- .sr2t(object)
+	retval <- .t_confint(tstat,df=object$df,level=NULL, # ignored
+											 level.lo=level.lo,level.hi=level.hi,
+											 type=type,cumulants=object$cumulants,
+											 inflate_by=inflate_by)
+	retval <- .t2sr(object,retval)
+	rownames(retval) <- .get_strat_names(object$sr)
+	return(retval)
+}
+
+
 # confidence intervals on the Sharpe ratio#FOLDUP
 
 #' @title Confidence Interval on (optimal) Signal-Noise Ratio
@@ -387,7 +411,7 @@ se.sr <- function(z, type=c("t","Lo","Mertens","Bao")) {
 #' @return A matrix (or vector) with columns giving lower and upper
 #' confidence limits for the parameter. These will be labelled as
 #' level.lo and level.hi in \%, \emph{e.g.} \code{"2.5 \%"}
-#' @seealso \code{\link{confint}}, \code{\link{se}}
+#' @seealso \code{\link{confint}}, \code{\link{se}}, \code{\link{predint}}
 #' @examples 
 #'
 #' # using "sr" class:
@@ -443,13 +467,7 @@ confint.sr <- function(object,parm,level=0.95,
 							 level.lo=(1-level)/2,level.hi=1-level.lo,
 							 type=c("exact","t","Z","Mertens","Bao"),...) {
 	type <- match.arg(type)
-	tstat <- .sr2t(object)
-	retval <- .t_confint(tstat,df=object$df,level=level,
-											 level.lo=level.lo,level.hi=level.hi,
-											 type=type,cumulants=object$cumulants)
-	retval <- .t2sr(object,retval)
-	rownames(retval) <- .get_strat_names(object$sr)
-	return(retval)
+	return(.genint(object,level.lo=level.lo,level.hi=level.hi,type=type))
 }
 #' @export
 #' @rdname confint
@@ -511,11 +529,12 @@ confint.del_sropt <- function(object,parm,level=0.95,
 #' given interval. The coverage is over repeated draws of both the past and
 #' future data, thus this computation takes into account error in both the
 #' estimate of Sharpe and the as yet unrealized returns.
-#' 
-#' @usage
+#' Coverage is approximate. Prediction intervals are computed by
+#' inflating a confidence interval by an amount which depends on the sample
+#' sizes.
 #'
-#' predint(x,oosdf,oosrescal=1/sqrt(oosdf+1),ope=NULL,level=0.95,
-#'				 level.lo=(1-level)/2,level.hi=1-level.lo)
+#' See \sQuote{The Sharpe Ratio: Statistics and Applications},
+#' sections 2.5.9 and 3.5.2.
 #'
 #' @param x a (non-empty) numeric vector of data values, or an
 #'    object of class \code{sr}.
@@ -535,17 +554,22 @@ confint.del_sropt <- function(object,parm,level=0.95,
 #' @param level the confidence level required.
 #' @param level.lo the lower confidence level required.
 #' @param level.hi the upper confidence level required.
+#' @param type which method to apply. Only methods based on an approximate
+#' standard error are supported.
+#' @note if \code{level.lo < 0} or \code{level.hi > 1}, \code{NaN} will be
+#' returned.
 #' @return A matrix (or vector) with columns giving lower and upper
 #' confidence limits for the parameter. These will be labelled as
 #' level.lo and level.hi in \%, \emph{e.g.} \code{"2.5 \%"}
 #' @seealso \code{\link{confint.sr}}.
+#' @template ref-tsrsa
 #' @export 
 #' @template etc
 #' @template sr
-#' @template ref-upsilon
 #' @examples 
 #'
 #' # should reject null
+#' set.seed(1234)
 #' etc <- predint(rnorm(1000,mean=0.5,sd=0.1),oosdf=127,ope=1)
 #' etc <- predint(matrix(rnorm(1000*5,mean=0.05),ncol=5),oosdf=63,ope=1)
 #'
@@ -566,33 +590,18 @@ confint.del_sropt <- function(object,parm,level=0.95,
 #'
 #' @export
 predint <- function(x,oosdf,oosrescal=1/sqrt(oosdf+1),ope=NULL,level=0.95,
-										level.lo=(1-level)/2,level.hi=1-level.lo) {
+										level.lo=(1-level)/2,level.hi=1-level.lo,
+										type=c("t","Z","Mertens","Bao")) {
+	type <- match.arg(type)
 	if (is.sr(x)) {
-		srx <- x
+		object <- x
 	} else {
-		srx <- as.sr(x,c0=0,ope=1,na.rm=TRUE)
+		object <- as.sr(x,c0=0,ope=1,na.rm=TRUE)
 	}
-	if (is.null(ope)) { ope <- srx$ope }
-	srx <- reannualize(srx,new.ope=1)
-	cols <- mapply(function(sx,dfx,rescalx) {
-		ocons <- sqrt(rescalx^2 + oosrescal^2)
-		udf <- c(dfx,oosdf)
-
-		ci <- lapply(c(level.lo,level.hi),function(lvl) {
-			if ((0 < lvl) && (lvl < 1)) {
-				yval <- sadists::qkprime(lvl,v1=udf[1],v2=udf[2],a=sx,b=ocons,order.max=5)
-				yval <- .annualize(yval,ope)
-			} else {
-				yval <- ifelse(lvl >= 1,Inf,-Inf)
-			}
-		})
-		retval <- matrix(unlist(ci),nrow=1)
-	},srx$sr,srx$df,srx$rescal)
-	retval <- matrix(t(cols),ncol=2)
-	colnames(retval) <- sapply(c(level.lo,level.hi),function(x) { sprintf("%g %%",100*x) })
-
-	rownames(retval) <- .get_strat_names(srx$sr)
-	retval
+	if (!is.null(ope)) { object <- reannualize(object,new.ope=ope) } 
+	inflate_by <- sqrt(1 + (object$df + 1) * oosrescal^2)
+	# have to rescale properly by oosrescal?
+	return(.genint(object,level.lo=level.lo,level.hi=level.hi,type=type,inflate_by=inflate_by))
 }
 #UNFOLD
 
@@ -715,7 +724,7 @@ T2.inference <- function(T2,df1,df2,...) {
 #'
 #' Spruill, M. C. "Computation of the maximum likelihood estimate of a noncentrality parameter." 
 #' Journal of multivariate analysis 18, no. 2 (1986): 216-224.
-#' \url{http://www.sciencedirect.com/science/article/pii/0047259X86900709}
+#' \url{https://www.sciencedirect.com/science/article/pii/0047259X86900709}
 #'
 #' @rdname inference
 #' @export inference
